#ifndef PARSEPORT_H____
#define PARSEPORT_H____

#define parseport_VERSION "20260329"

extern int parseport_(unsigned char *, const char *);
extern int parseport(unsigned char *, const char *);

#endif
