#ifndef PARSEHOSTPORT_H____
#define PARSEHOSTPORT_H____

#define parsehostport_VERSION "20260425"
#define parsehostport_HOSTBYTES 256
#define parsehostport_PORTBYTES 6

extern int parsehostport(char *, char *, const char *);

#endif
